Index: src/wp-admin/includes/image.php
===================================================================
--- src/wp-admin/includes/image.php	(revision 46384)
+++ src/wp-admin/includes/image.php	(working copy)
@@ -203,6 +203,7 @@
  */
 function wp_create_image_subsizes( $file, $attachment_id ) {
 	$imagesize = @getimagesize( $file );
+	$max_image_size = 2560;
 
 	if ( empty( $imagesize ) ) {
 		// File is not an image.
@@ -235,11 +236,12 @@
 	 *
 	 * @since 5.3.0
 	 *
 	 * @param array  $imagesize     Indexed array of the image width and height (in that order).
 	 * @param string $file          Full path to the uploaded image file.
 	 * @param int    $attachment_id Attachment post ID.
 	 */
-	$threshold = (int) apply_filters( 'big_image_size_threshold', 2560, $imagesize, $file, $attachment_id );
+	$threshold = (int) apply_filters( 'big_image_size_threshold', $max_image_size, $imagesize, $file, $attachment_id );
 
 	// If the original image's dimensions are over the threshold, scale the image
 	// and use it as the "full" size.
@@ -235,11 +236,12 @@
 	 * @since 5.3.0
 	 *
-	 * @param array  $imagesize     Indexed array of the image width and height (in that order).
-	 * @param string $file          Full path to the uploaded image file.
-	 * @param int    $attachment_id Attachment post ID.
+	 * @param int 	 $max_image_size Max image available size.
+	 * @param array  $imagesize      Indexed array of the image width and height (in that order).
+	 * @param string $file           Full path to the uploaded image file.
+	 * @param int    $attachment_id  Attachment post ID.
 	 */
